==> gpustack_runtime-0.1.5.tar.gz: gpustack_runtime-0.1.5/gpustack_runtime/detector/__init__.py <==
from __future__ import annotations

from .__types__ import (
    Detector,
    Device,
    Devices,
    ManufacturerEnum,
    backend_to_manufacturer,
    manufacturer_to_backend,
    supported_backends,
    supported_manufacturers,
)
from .amd import AMDDetector
from .ascend import AscendDetector
from .nvidia import NVIDIADetector

detectors: list[Detector] = [
    AMDDetector(),
    AscendDetector(),
    NVIDIADetector(),
]


def detect_backend(fast: bool = True) -> str | list[str] | None:
    """
    Detect the backend of the available devices.

    Args:
        fast (bool):
            If True, return the first detected backend.
            Otherwise, return a list of all detected backends.

    Returns:
        A string of the detected backend if `fast` is True and a backend is found.
        A list of detected backends if `fast` is False.
        None if no backend is found.

    """
    backends: list[str] = []

    for det in detectors:
        if not det.is_supported():
            continue

        if fast:
            return det.backend

        if backend := det.backend:
            backends.append(backend)

    if backends:
        return backends
    return None


def detect_devices(fast: bool = True) -> Devices:
    """
    Detect all available devices.

    Args:
        fast (bool):
            If True, return devices from the first supported detector.
            Otherwise, return devices from all supported detectors.

    Returns:
        A list of detected devices.
        Empty list if no devices are found.

    """
    devices: Devices = []

    for det in detectors:
        if not det.is_supported():
            continue

        if fast:
            return det.detect()

        if devs := det.detect():
            devices.extend(devs)

    return devices


__all__ = [
    "Device",
    "Devices",
    "ManufacturerEnum",
    "backend_to_manufacturer",
    "detect_backend",
    "detect_devices",
    "manufacturer_to_backend",
    "supported_backends",
    "supported_manufacturers",
]

==> gpustack_runtime-0.1.6.tar.gz: gpustack_runtime-0.1.6/gpustack_runtime/detector/__init__.py <==
from __future__ import annotations

from .__types__ import (
    Detector,
    Device,
    Devices,
    ManufacturerEnum,
    backend_to_manufacturer,
    manufacturer_to_backend,
    supported_backends,
    supported_manufacturers,
)
from .amd import AMDDetector
from .ascend import AscendDetector
from .cambricon import CambriconDetector
from .hygon import HygonDetector
from .iluvatar import IluvatarDetector
from .mthreads import MThreadsDetector
from .nvidia import NVIDIADetector

detectors: list[Detector] = [
    AMDDetector(),
    AscendDetector(),
    CambriconDetector(),
    HygonDetector(),
    IluvatarDetector(),
    MThreadsDetector(),
    NVIDIADetector(),
]


def detect_backend(fast: bool = True) -> str | list[str] | None:
    """
    Detect the backend of the available devices.

    Args:
        fast (bool):
            If True, return the first detected backend.
            Otherwise, return a list of all detected backends.

    Returns:
        A string of the detected backend if `fast` is True and a backend is found.
        A list of detected backends if `fast` is False.
        None if no backend is found.

    """
    backends: list[str] = []

    for det in detectors:
        if not det.is_supported():
            continue

        if fast:
            return det.backend

        if backend := det.backend:
            backends.append(backend)

    if backends:
        return backends
    return None


def detect_devices(fast: bool = True) -> Devices:
    """
    Detect all available devices.

    Args:
        fast (bool):
            If True, return devices from the first supported detector.
            Otherwise, return devices from all supported detectors.

    Returns:
        A list of detected devices.
        Empty list if no devices are found.

    """
    devices: Devices = []

    for det in detectors:
        if not det.is_supported():
            continue

        if fast:
            return det.detect()

        if devs := det.detect():
            devices.extend(devs)

    return devices


__all__ = [
    "Device",
    "Devices",
    "ManufacturerEnum",
    "backend_to_manufacturer",
    "detect_backend",
    "detect_devices",
    "manufacturer_to_backend",
    "supported_backends",
    "supported_manufacturers",
]
